# Open Music Plugins

Provides the API needed to create plugins for the application [OpenMusic](https://github.com/Frankanator8/openmusic)

## Features
- Provides the class OpenMusicClient needed for plugins

## Installation
```bash
pip install openmusic_api
```

### More info
Check out the OpenMusic [wiki](https://github.com/Frankanator8/openmusic/wiki) for full documentation on how to use.